/*jslint vars: true, plusplus: true, devel: true, nomen: true, regexp: true, indent: 4, maxerr: 50 */
/*global window, document, CSInterface*/
/*

    Responsible for overwriting CSS at runtime according to CC app
    settings as defined by the end user.

 */

var themeManager = (function () {

  'use strict';
  var csInterface = new CSInterface();

  // Update the theme with the AppSkinInfo 
  function setCurrentAppSkinInfoTheme(appSkinInfo) {

    // Extract the red and keep the sentinel
    var sentinelColor = appSkinInfo.panelBackgroundColor.color.red;

    // Check for red value, if >128, it is light.
    if (sentinelColor > 128) {

      // Change the css to light theme.
      updateCssTheme("light");
    } else {
      // Change the css to dark theme.
      updateCssTheme("dark");
    }
  }

  function updateCssTheme(theme) {

    // Get the css tag of theme in html.
    var cssTag = document.getElementById("host-theme");

    // Write it relative path with theme file name.
    var cssTheme = `./css/theme.${theme}.css?v=${Math.random()}`;

    // Set the attribute.
    cssTag.setAttribute('href', cssTheme);
  }

  function onAppThemeColorChanged(event) {
    // On chagne in theme event, take the appskin info
    var appSkinInfo = csInterface.getHostEnvironment().appSkinInfo;

    // Update the theme css accordingly...
    setCurrentAppSkinInfoTheme(appSkinInfo);
  }

  function init() {

    try {

      // Check if in adobe env.
      if (window.__adobe_cep__) {
        // Get the appskin of host.
        var appSkinInfo = csInterface.getHostEnvironment().appSkinInfo;

        // Set the current theme based on appskin info
        setCurrentAppSkinInfoTheme(appSkinInfo);

        // listen to theme color change events.
        csInterface.addEventListener(CSInterface.THEME_COLOR_CHANGED_EVENT, onAppThemeColorChanged);
      }
      // Check if it is office plguins.
      else if (window.office) {

        // Stick to default theme. 
        updateCssTheme("light");
      }

    } // If any error above.
    catch (error) {

      // Stick to default theme. 
      updateCssTheme("dark");
    }

  }

  return {
    init: init
  };

}());